"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertiesManager = exports.PropertiesRollback = void 0;
/* eslint-disable @typescript-eslint/no-non-null-assertion */
const internal_1 = require("@fluidframework/core-utils/internal");
const constants_js_1 = require("./constants.js");
const properties_js_1 = require("./properties.js");
/**
 * @legacy
 * @alpha
 *
 * @deprecated - This enum should not be used externally and will be removed in a subsequent release.
 *
 * @privateRemarks This enum should be made internal after the deprecation period
 */
var PropertiesRollback;
(function (PropertiesRollback) {
    /**
     * Not in a rollback
     */
    PropertiesRollback[PropertiesRollback["None"] = 0] = "None";
    /**
     * Rollback
     */
    PropertiesRollback[PropertiesRollback["Rollback"] = 1] = "Rollback";
})(PropertiesRollback || (exports.PropertiesRollback = PropertiesRollback = {}));
/**
 * @legacy
 * @alpha
 *
 * @deprecated - This class should not be used externally and will be removed in a subsequent release.
 *
 * @privateRemarks This class should be made internal after the deprecation period
 */
class PropertiesManager {
    ackPendingProperties(annotateOp) {
        this.decrementPendingCounts(annotateOp.props);
    }
    decrementPendingCounts(props) {
        for (const [key, value] of Object.entries(props)) {
            if (value !== undefined && this.pendingKeyUpdateCount?.[key] !== undefined) {
                (0, internal_1.assert)(this.pendingKeyUpdateCount[key] > 0, 0x05c /* "Trying to update more annotate props than do exist!" */);
                this.pendingKeyUpdateCount[key]--;
                if (this.pendingKeyUpdateCount?.[key] === 0) {
                    // eslint-disable-next-line @typescript-eslint/no-dynamic-delete
                    delete this.pendingKeyUpdateCount[key];
                }
            }
        }
    }
    addProperties(oldProps, newProps, seq, collaborating = false, rollback = PropertiesRollback.None) {
        this.pendingKeyUpdateCount ?? (this.pendingKeyUpdateCount = (0, properties_js_1.createMap)());
        // Clean up counts for rolled back edits before modifying oldProps
        if (collaborating && rollback === PropertiesRollback.Rollback) {
            this.decrementPendingCounts(newProps);
        }
        const shouldModifyKey = (key) => {
            if (seq === constants_js_1.UnassignedSequenceNumber ||
                seq === constants_js_1.UniversalSequenceNumber ||
                this.pendingKeyUpdateCount?.[key] === undefined) {
                return true;
            }
            return false;
        };
        const deltas = {};
        for (const [key, newValue] of Object.entries(newProps)) {
            if (newValue === undefined) {
                continue;
            }
            if (collaborating) {
                if (seq === constants_js_1.UnassignedSequenceNumber) {
                    if (this.pendingKeyUpdateCount?.[key] === undefined) {
                        this.pendingKeyUpdateCount[key] = 0;
                    }
                    this.pendingKeyUpdateCount[key]++;
                }
                else if (!shouldModifyKey(key)) {
                    continue;
                }
            }
            const previousValue = oldProps[key];
            // The delta should be null if undefined, as that's how we encode delete
            // eslint-disable-next-line unicorn/no-null
            deltas[key] = previousValue === undefined ? null : previousValue;
            if (newValue === null) {
                // eslint-disable-next-line @typescript-eslint/no-dynamic-delete
                delete oldProps[key];
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
                oldProps[key] = newValue;
            }
        }
        return deltas;
    }
    copyTo(oldProps, newProps, newManager) {
        if (oldProps) {
            // eslint-disable-next-line no-param-reassign
            newProps ?? (newProps = (0, properties_js_1.createMap)());
            if (!newManager) {
                throw new Error("Must provide new PropertyManager");
            }
            (0, properties_js_1.extend)(newProps, oldProps);
            if (this.pendingKeyUpdateCount) {
                newManager.pendingKeyUpdateCount = (0, properties_js_1.clone)(this.pendingKeyUpdateCount);
            }
        }
        return newProps;
    }
    /**
     * Determines if all of the defined properties in a given property set are pending.
     */
    hasPendingProperties(props) {
        for (const [key, value] of Object.entries(props)) {
            if (value !== undefined && this.pendingKeyUpdateCount?.[key] === undefined) {
                return false;
            }
        }
        return true;
    }
    hasPendingProperty(key) {
        return (this.pendingKeyUpdateCount?.[key] ?? 0) > 0;
    }
}
exports.PropertiesManager = PropertiesManager;
//# sourceMappingURL=segmentPropertiesManager.js.map